<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>RDHPIPlayStream</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>No such file or directory</source>
        <translation>Keine solche Datei oder Verzeichnis</translation>
    </message>
    <message>
        <source>No output stream available</source>
        <translation>Kein Outputstream verfügbar</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Stream ist schon geöffnet</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Unbekannter Fehler:</translation>
    </message>
    <message>
        <source>Unknown RDHpiPlayStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPIRecordStream</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to create/open file</source>
        <translation>Kann die Datei nicht erstellen/öffnen</translation>
    </message>
    <message>
        <source>Input stream unavailable</source>
        <translation>Eingangsstream nicht verfügbar</translation>
    </message>
    <message>
        <source>Stream is already open</source>
        <translation>Stream ist schon geöffnet</translation>
    </message>
    <message>
        <source>Unknown Error:</source>
        <translation type="obsolete">Unbekannter Fehler:</translation>
    </message>
    <message>
        <source>Unknown RDHpiRecordStream Error:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDHPISoundCard</name>
    <message>
        <source>Input Stream</source>
        <translation>Eingansstream</translation>
    </message>
    <message>
        <source>Output Stream</source>
        <translation>Ausgangsstream</translation>
    </message>
    <message>
        <source>Input Port</source>
        <translation>Eingangsport</translation>
    </message>
    <message>
        <source>Output Port</source>
        <translation>Ausgangsport</translation>
    </message>
</context>
</TS>
